from vespa.configuration.vt import VT

def abortondocumenterror(*c, **kwargs) -> VT: ...
def accesslog(*c, **kwargs) -> VT: ...
def admin(*c, **kwargs) -> VT: ...
def adminserver(*c, **kwargs) -> VT: ...
def age(*c, **kwargs) -> VT: ...
def api_key_secret_ref(*c, **kwargs) -> VT: ...
def batching(*c, **kwargs) -> VT: ...
def binding(*c, **kwargs) -> VT: ...
def bucket_splitting(*c, **kwargs) -> VT: ...
def cache(*c, **kwargs) -> VT: ...
def certificate(*c, **kwargs) -> VT: ...
def chain(*c, **kwargs) -> VT: ...
def chunk(*c, **kwargs) -> VT: ...
def client(*c, **kwargs) -> VT: ...
def clients(*c, **kwargs) -> VT: ...
def cluster_controller(*c, **kwargs) -> VT: ...
def clustercontroller(*c, **kwargs) -> VT: ...
def clustercontrollers(*c, **kwargs) -> VT: ...
def component(*c, **kwargs) -> VT: ...
def components(*c, **kwargs) -> VT: ...
def compression(*c, **kwargs) -> VT: ...
def concurrency(*c, **kwargs) -> VT: ...
def config(*c, **kwargs) -> VT: ...
def configserver(*c, **kwargs) -> VT: ...
def configservers(*c, **kwargs) -> VT: ...
def conservative(*c, **kwargs) -> VT: ...
def container(*c, **kwargs) -> VT: ...
def content(*c, **kwargs) -> VT: ...
def coverage(*c, **kwargs) -> VT: ...
def dimensions(*c, **kwargs) -> VT: ...
def disk(*c, **kwargs) -> VT: ...
def disk_limit_factor(*c, **kwargs) -> VT: ...
def diskbloatfactor(*c, **kwargs) -> VT: ...
def dispatch(*c, **kwargs) -> VT: ...
def dispatch_policy(*c, **kwargs) -> VT: ...
def distribution(*c, **kwargs) -> VT: ...
def document(*c, **kwargs) -> VT: ...
def document_api(*c, **kwargs) -> VT: ...
def document_processing(*c, **kwargs) -> VT: ...
def document_token_id(*c, **kwargs) -> VT: ...
def documentprocessor(*c, **kwargs) -> VT: ...
def documents(*c, **kwargs) -> VT: ...
def endpoint(*c, **kwargs) -> VT: ...
def engine(*c, **kwargs) -> VT: ...
def environment_variables(*c, **kwargs) -> VT: ...
def execution_mode(*c, **kwargs) -> VT: ...
def federation(*c, **kwargs) -> VT: ...
def feeding(*c, **kwargs) -> VT: ...
def filtering(*c, **kwargs) -> VT: ...
def flush_on_shutdown(*c, **kwargs) -> VT: ...
def flushstrategy(*c, **kwargs) -> VT: ...
def gpu(*c, **kwargs) -> VT: ...
def gpu_device(*c, **kwargs) -> VT: ...
def group(*c, **kwargs) -> VT: ...
def groups_allowed_down_ratio(*c, **kwargs) -> VT: ...
def handler(*c, **kwargs) -> VT: ...
def http(*c, **kwargs) -> VT: ...
def ignore_undefined_fields(*c, **kwargs) -> VT: ...
def include(*c, **kwargs) -> VT: ...
def index(*c, **kwargs) -> VT: ...
def init_progress_time(*c, **kwargs) -> VT: ...
def initialize(*c, **kwargs) -> VT: ...
def interop_threads(*c, **kwargs) -> VT: ...
def interval(*c, **kwargs) -> VT: ...
def intraop_threads(*c, **kwargs) -> VT: ...
def io_(*c, **kwargs) -> VT: ...
def jvm(*c, **kwargs) -> VT: ...
def level(*c, **kwargs) -> VT: ...
def lidspace(*c, **kwargs) -> VT: ...
def logstore(*c, **kwargs) -> VT: ...
def maintenance(*c, **kwargs) -> VT: ...
def max_bloat_factor(*c, **kwargs) -> VT: ...
def max_concurrent(*c, **kwargs) -> VT: ...
def max_document_tokens(*c, **kwargs) -> VT: ...
def max_hits_per_partition(*c, **kwargs) -> VT: ...
def max_premature_crashes(*c, **kwargs) -> VT: ...
def max_query_tokens(*c, **kwargs) -> VT: ...
def max_tokens(*c, **kwargs) -> VT: ...
def max_wait_after_coverage_factor(*c, **kwargs) -> VT: ...
def maxage(*c, **kwargs) -> VT: ...
def maxfilesize(*c, **kwargs) -> VT: ...
def maxmemorygain(*c, **kwargs) -> VT: ...
def maxpendingbytes(*c, **kwargs) -> VT: ...
def maxpendingdocs(*c, **kwargs) -> VT: ...
def maxsize(*c, **kwargs) -> VT: ...
def maxsize_percent(*c, **kwargs) -> VT: ...
def mbusport(*c, **kwargs) -> VT: ...
def memory(*c, **kwargs) -> VT: ...
def memory_limit_factor(*c, **kwargs) -> VT: ...
def merges(*c, **kwargs) -> VT: ...
def min_active_docs_coverage(*c, **kwargs) -> VT: ...
def min_distributor_up_ratio(*c, **kwargs) -> VT: ...
def min_node_ratio_per_group(*c, **kwargs) -> VT: ...
def min_redundancy(*c, **kwargs) -> VT: ...
def min_storage_up_ratio(*c, **kwargs) -> VT: ...
def min_wait_after_coverage_factor(*c, **kwargs) -> VT: ...
def minimum(*c, **kwargs) -> VT: ...
def model(*c, **kwargs) -> VT: ...
def model_config_override(*c, **kwargs) -> VT: ...
def model_evaluation(*c, **kwargs) -> VT: ...
def models(*c, **kwargs) -> VT: ...
def native(*c, **kwargs) -> VT: ...
def niceness(*c, **kwargs) -> VT: ...
def node(*c, **kwargs) -> VT: ...
def nodes(*c, **kwargs) -> VT: ...
def normalize(*c, **kwargs) -> VT: ...
def onnx(*c, **kwargs) -> VT: ...
def onnx_execution_mode(*c, **kwargs) -> VT: ...
def onnx_gpu_device(*c, **kwargs) -> VT: ...
def onnx_interop_threads(*c, **kwargs) -> VT: ...
def onnx_intraop_threads(*c, **kwargs) -> VT: ...
def persearch(*c, **kwargs) -> VT: ...
def persistence_threads(*c, **kwargs) -> VT: ...
def pooling_strategy(*c, **kwargs) -> VT: ...
def prepend(*c, **kwargs) -> VT: ...
def processing(*c, **kwargs) -> VT: ...
def processor(*c, **kwargs) -> VT: ...
def proton(*c, **kwargs) -> VT: ...
def provider(*c, **kwargs) -> VT: ...
def prune(*c, **kwargs) -> VT: ...
def quantization(*c, **kwargs) -> VT: ...
def query(*c, **kwargs) -> VT: ...
def query_timeout(*c, **kwargs) -> VT: ...
def query_token_id(*c, **kwargs) -> VT: ...
def read(*c, **kwargs) -> VT: ...
def redundancy(*c, **kwargs) -> VT: ...
def removed_db(*c, **kwargs) -> VT: ...
def renderer(*c, **kwargs) -> VT: ...
def requestthreads(*c, **kwargs) -> VT: ...
def resource_limits(*c, **kwargs) -> VT: ...
def resources(*c, **kwargs) -> VT: ...
def retrydelay(*c, **kwargs) -> VT: ...
def retryenabled(*c, **kwargs) -> VT: ...
def route(*c, **kwargs) -> VT: ...
def search(*c, **kwargs) -> VT: ...
def searchable_copies(*c, **kwargs) -> VT: ...
def searcher(*c, **kwargs) -> VT: ...
def searchnode(*c, **kwargs) -> VT: ...
def secret_store(*c, **kwargs) -> VT: ...
def secrets(*c, **kwargs) -> VT: ...
def server(*c, **kwargs) -> VT: ...
def services(*c, **kwargs) -> VT: ...
def slobrok(*c, **kwargs) -> VT: ...
def slobroks(*c, **kwargs) -> VT: ...
def stable_state_period(*c, **kwargs) -> VT: ...
def store(*c, **kwargs) -> VT: ...
def summary(*c, **kwargs) -> VT: ...
def sync_transactionlog(*c, **kwargs) -> VT: ...
def term_score_threshold(*c, **kwargs) -> VT: ...
def threadpool(*c, **kwargs) -> VT: ...
def threads(*c, **kwargs) -> VT: ...
def time_(*c, **kwargs) -> VT: ...
def timeout(*c, **kwargs) -> VT: ...
def token(*c, **kwargs) -> VT: ...
def tokenizer_model(*c, **kwargs) -> VT: ...
def tokenizer_vocab(*c, **kwargs) -> VT: ...
def top_k_probability(*c, **kwargs) -> VT: ...
def total(*c, **kwargs) -> VT: ...
def tracelevel(*c, **kwargs) -> VT: ...
def transactionlog(*c, **kwargs) -> VT: ...
def transformer_attention_mask(*c, **kwargs) -> VT: ...
def transformer_end_sequence_token(*c, **kwargs) -> VT: ...
def transformer_input_ids(*c, **kwargs) -> VT: ...
def transformer_mask_token(*c, **kwargs) -> VT: ...
def transformer_model(*c, **kwargs) -> VT: ...
def transformer_output(*c, **kwargs) -> VT: ...
def transformer_pad_token(*c, **kwargs) -> VT: ...
def transformer_start_sequence_token(*c, **kwargs) -> VT: ...
def transformer_token_type_ids(*c, **kwargs) -> VT: ...
def transition_time(*c, **kwargs) -> VT: ...
def truncate(*c, **kwargs) -> VT: ...
def tuning(*c, **kwargs) -> VT: ...
def type_(*c, **kwargs) -> VT: ...
def unpack(*c, **kwargs) -> VT: ...
def visibility_delay(*c, **kwargs) -> VT: ...
def visitors(*c, **kwargs) -> VT: ...
def warmup(*c, **kwargs) -> VT: ...
def zookeeper(*c, **kwargs) -> VT: ...
